package com.ruoyi.project.document.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.document.mapper.TPublicdocmenuMapper;
import com.ruoyi.project.document.domain.TPublicdocmenu;
import com.ruoyi.project.document.service.ITPublicdocmenuService;

import javax.annotation.Resource;

/**
 * 公共盘文档目录Service业务层处理
 *
 * @author ruoyi
 * @date 2020-12-03
 */
@Service
public class TPublicdocmenuServiceImpl implements ITPublicdocmenuService
{
    @Resource
    private TPublicdocmenuMapper tPublicdocmenuMapper;

    /**
     * 查询公共盘文档目录
     *
     * @param id 公共盘文档目录ID
     * @return 公共盘文档目录
     */
    @Override
    public TPublicdocmenu selectTPublicdocmenuById(Long id)
    {
        return tPublicdocmenuMapper.selectTPublicdocmenuById(id);
    }

    /**
     * 查询公共盘文档ID
     *
     * @param catano 公共盘文档目录编号
     * @return 公共盘文档目录
     */
    @Override
    public TPublicdocmenu selectTPublicdocmenuByCatano(String catano)
    {
        return tPublicdocmenuMapper.selectTPublicdocmenuByCatano(catano);
    }

    /**
     * 查询公共盘文档目录列表
     *
     * @param tPublicdocmenu 公共盘文档目录
     * @return 公共盘文档目录
     */
    @Override
    public List<TPublicdocmenu> selectTPublicdocmenuList(TPublicdocmenu tPublicdocmenu)
    {
        return tPublicdocmenuMapper.selectTPublicdocmenuList(tPublicdocmenu);
    }

    /**
     * 新增公共盘文档目录
     *
     * @param tPublicdocmenu 公共盘文档目录
     * @return 结果
     */
    @Override
    public int insertTPublicdocmenu(TPublicdocmenu tPublicdocmenu)
    {
        return tPublicdocmenuMapper.insertTPublicdocmenu(tPublicdocmenu);
    }

    /**
     * 修改公共盘文档目录
     *
     * @param tPublicdocmenu 公共盘文档目录
     * @return 结果
     */
    @Override
    public int updateTPublicdocmenu(TPublicdocmenu tPublicdocmenu)
    {
        return tPublicdocmenuMapper.updateTPublicdocmenu(tPublicdocmenu);
    }

    /**
     * 批量删除公共盘文档目录
     *
     * @param ids 需要删除的公共盘文档目录ID
     * @return 结果
     */
    @Override
    public int deleteTPublicdocmenuByIds(Long[] ids)
    {
        return tPublicdocmenuMapper.deleteTPublicdocmenuByIds(ids);
    }

    /**
     * 删除公共盘文档目录信息
     *
     * @param id 公共盘文档目录ID
     * @return 结果
     */
    @Override
    public int deleteTPublicdocmenuById(Long id)
    {
        return tPublicdocmenuMapper.deleteTPublicdocmenuById(id);
    }
}
